#ifndef _SEQUENCE_BROWSER_SIDEBAR_H
#define _SEQUENCE_BROWSER_SIDEBAR_H

#include <vector>

#include <boost/shared_ptr.hpp>

#include <QVBoxLayout>
#include <QWidget>
#include "qui/seqbrowser/SequenceBrowser.hpp"
#include "qui/seqbrowser/SequenceDescription.hpp"
#include "alg/glsequence.hpp"

//! store a collection of sequence descriptions for the SequenceBrowserWidget
class SequenceBrowserSidebar : public QWidget
{
  Q_OBJECT

public:
  //! pointer to our sequence description widget
  typedef SequenceDescription *seq_description_type;
  //! an STL collection of our sequence description widget
  typedef std::vector<seq_description_type> collection;
  typedef collection::size_type size_type;
  typedef collection::iterator iterator;
  enum SidebarSide { Left, Right };

  SequenceBrowserSidebar(QWidget *parent = 0);

  //! clear our list of descriptions
  void clear();
  //! how many items are we storing
  size_t size() const;
  //! set the glsequences we're going to be displaying
  void setSequences(std::vector<boost::shared_ptr<GlSequence> > );

  collection descriptions;
public slots:
  //! update the reported sequence position for each of our sequences
  /*! for example when the right side is at position 3000 call 
   *  iterate over each sequence and get its rightbase pair value
   */
  //void updatePositionValues(float left, float right);

private:
  QVBoxLayout layout;
  //! for updating positions we need to know which side we're on
  //SidebarSide sidebar_side;
};
#endif
